# AI Learning Project

这是一个基于Python和OpenAI的AI学习项目。

## 环境设置

### 初次下载项目

如果你是第一次克隆或下载这个项目，请按照以下步骤使用 `uv` 同步虚拟环境和依赖：

1. **确保已安装 uv**
   ```bash
   # 如果还没有安装 uv，可以使用以下命令安装
   curl -LsSf https://astral.sh/uv/install.sh | sh
   ```

2. **同步虚拟环境和依赖**
   ```bash
   # 进入项目目录
   cd ai_learning
   
   # 使用 uv 同步环境和依赖
   uv sync
   ```

   这个命令会：
   - 自动创建虚拟环境（如果不存在）
   - 安装 `pyproject.toml` 中定义的所有依赖
   - 根据 `uv.lock` 文件确保依赖版本的一致性

3. **激活虚拟环境**
   ```bash
   # 激活虚拟环境
   source .venv/bin/activate
   
   # 或者使用 uv run 来直接在虚拟环境中运行命令
   uv run python your_script.py
   ```

### 添加新依赖

如果你希望在项目中添加新的依赖包，请按照以下步骤操作：

1. **添加依赖**
   ```bash
   # 添加生产依赖
   uv add package_name
   
   # 添加开发依赖
   uv add --dev package_name
   
   # 添加特定版本的依赖
   uv add "package_name>=1.0.0"
   ```

2. **示例**
   ```bash
   # 添加常用的数据科学包
   uv add pandas numpy matplotlib
   
   # 添加开发工具
   uv add --dev pytest black flake8
   ```

3. **更新锁定文件**
   ```bash
   # uv add 命令会自动更新 uv.lock 文件
   # 如果需要手动更新所有依赖到最新版本
   uv lock --upgrade
   ```

### 其他常用命令

```bash
# 查看已安装的包
uv pip list

# 移除依赖
uv remove package_name

# 在虚拟环境中运行命令
uv run python script.py

# 在虚拟环境中运行 Jupyter notebook
uv run jupyter notebook
```

## 项目结构

```
ai_learning/
├── README.md           # 项目说明文档
├── pyproject.toml      # 项目配置和依赖定义
├── uv.lock            # 依赖锁定文件（确保环境一致性）
├── uv.toml            # uv 配置文件
└── 林兆新/             # 项目代码目录
```

## 使用说明

1. 确保已按照上述步骤设置好环境
2. 激活虚拟环境或使用 `uv run` 命令
3. 开始你的AI学习之旅！

## 注意事项

- 请不要手动编辑 `uv.lock` 文件，它由 uv 自动管理
- 建议将 `.venv/` 目录添加到 `.gitignore` 中（如果使用 Git）
- 在团队协作时，确保所有成员都使用 `uv sync` 来保持环境一致性